pub fn GetWorkspaceConfigurationPath() -> ActionEffect<Arc<dyn WorkspaceProvider>, CommonError, Option<PathBuf>>Expand description
Creates an effect that, when executed, will retrieve the file path of the
current workspace’s configuration file (e.g., the .code-workspace file).
It uses the WorkspaceProvider capability from the environment.
Returns
An ActionEffect that resolves with an Option<PathBuf>, containing the
path if a workspace configuration file is open, or None otherwise.